@@ -1,8 +1,7 @@
 from typing import Iterable
 
-from contek_viper.execution.execution_service_pb2 import SubmitMarketSignalsRequest
+from contek_viper.execution.execution_service_pb2 import MarketSignal, SubmitMarketSignalsRequest
 from contek_viper.execution.execution_service_pb2_grpc import ExecutionServiceStub
-from contek_viper.execution.market_signal_pb2 import MarketSignal
 
 
 class AccountSession:
