@@ -4,6 +4,7 @@ import grpc
 
 from contek_viper.account_session import AccountSession
 from contek_viper.execution.execution_service_pb2_grpc import ExecutionServiceStub
+from contek_viper.trigger_api import TriggerApi
 
 
 class ViperClient:
@@ -19,3 +20,6 @@ class ViperClient:
 
     def session(self, exchange: str, account: str) -> AccountSession:
         return AccountSession(exchange, account, self._stub)
+
+    def trigger(self, trigger_name: str) -> TriggerApi:
+        return TriggerApi(trigger_name, self._stub)
